from lakefs_client.paths.repositories_repository_branches_branch_commits.get import ApiForget
from lakefs_client.paths.repositories_repository_branches_branch_commits.post import ApiForpost


class RepositoriesRepositoryBranchesBranchCommits(
    ApiForget,
    ApiForpost,
):
    pass



from lakefs_client.paths.auth_users_user_id_credentials.get import ApiForget
from lakefs_client.paths.auth_users_user_id_credentials.post import ApiForpost


class AuthUsersUserIdCredentials(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class FindMergeBaseResult(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "destination_commit_id",
            "base_commit_id",
            "source_commit_id",
        }
        
        class properties:
            source_commit_id = schemas.StrSchema
            destination_commit_id = schemas.StrSchema
            base_commit_id = schemas.StrSchema
            __annotations__ = {
                "source_commit_id": source_commit_id,
                "destination_commit_id": destination_commit_id,
                "base_commit_id": base_commit_id,
            }
    
    destination_commit_id: MetaOapg.properties.destination_commit_id
    base_commit_id: MetaOapg.properties.base_commit_id
    source_commit_id: MetaOapg.properties.source_commit_id
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["source_commit_id"]) -> MetaOapg.properties.source_commit_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["destination_commit_id"]) -> MetaOapg.properties.destination_commit_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["base_commit_id"]) -> MetaOapg.properties.base_commit_id: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["source_commit_id", "destination_commit_id", "base_commit_id", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["source_commit_id"]) -> MetaOapg.properties.source_commit_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["destination_commit_id"]) -> MetaOapg.properties.destination_commit_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["base_commit_id"]) -> MetaOapg.properties.base_commit_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["source_commit_id", "destination_commit_id", "base_commit_id", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        destination_commit_id: typing.Union[MetaOapg.properties.destination_commit_id, str, ],
        base_commit_id: typing.Union[MetaOapg.properties.base_commit_id, str, ],
        source_commit_id: typing.Union[MetaOapg.properties.source_commit_id, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'FindMergeBaseResult':
        return super().__new__(
            cls,
            *_args,
            destination_commit_id=destination_commit_id,
            base_commit_id=base_commit_id,
            source_commit_id=source_commit_id,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class ObjectStageCreation(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "physical_address",
            "size_bytes",
            "checksum",
        }
        
        class properties:
            physical_address = schemas.StrSchema
            checksum = schemas.StrSchema
            size_bytes = schemas.Int64Schema
            mtime = schemas.Int64Schema
        
            @staticmethod
            def metadata() -> typing.Type['ObjectUserMetadata']:
                return ObjectUserMetadata
            content_type = schemas.StrSchema
            __annotations__ = {
                "physical_address": physical_address,
                "checksum": checksum,
                "size_bytes": size_bytes,
                "mtime": mtime,
                "metadata": metadata,
                "content_type": content_type,
            }
    
    physical_address: MetaOapg.properties.physical_address
    size_bytes: MetaOapg.properties.size_bytes
    checksum: MetaOapg.properties.checksum
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["physical_address"]) -> MetaOapg.properties.physical_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["checksum"]) -> MetaOapg.properties.checksum: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["size_bytes"]) -> MetaOapg.properties.size_bytes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mtime"]) -> MetaOapg.properties.mtime: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> 'ObjectUserMetadata': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["content_type"]) -> MetaOapg.properties.content_type: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["physical_address", "checksum", "size_bytes", "mtime", "metadata", "content_type", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["physical_address"]) -> MetaOapg.properties.physical_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["checksum"]) -> MetaOapg.properties.checksum: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["size_bytes"]) -> MetaOapg.properties.size_bytes: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mtime"]) -> typing.Union[MetaOapg.properties.mtime, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union['ObjectUserMetadata', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["content_type"]) -> typing.Union[MetaOapg.properties.content_type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["physical_address", "checksum", "size_bytes", "mtime", "metadata", "content_type", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        physical_address: typing.Union[MetaOapg.properties.physical_address, str, ],
        size_bytes: typing.Union[MetaOapg.properties.size_bytes, decimal.Decimal, int, ],
        checksum: typing.Union[MetaOapg.properties.checksum, str, ],
        mtime: typing.Union[MetaOapg.properties.mtime, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        metadata: typing.Union['ObjectUserMetadata', schemas.Unset] = schemas.unset,
        content_type: typing.Union[MetaOapg.properties.content_type, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ObjectStageCreation':
        return super().__new__(
            cls,
            *_args,
            physical_address=physical_address,
            size_bytes=size_bytes,
            checksum=checksum,
            mtime=mtime,
            metadata=metadata,
            content_type=content_type,
            _configuration=_configuration,
            **kwargs,
        )

from lakefs_client.model.object_user_metadata import ObjectUserMetadata



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class Pagination(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "max_per_page",
            "has_more",
            "next_offset",
            "results",
        }
        
        class properties:
            has_more = schemas.BoolSchema
            next_offset = schemas.StrSchema
            
            
            class results(
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    inclusive_minimum = 0
            
            
            class max_per_page(
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    inclusive_minimum = 0
            __annotations__ = {
                "has_more": has_more,
                "next_offset": next_offset,
                "results": results,
                "max_per_page": max_per_page,
            }
    
    max_per_page: MetaOapg.properties.max_per_page
    has_more: MetaOapg.properties.has_more
    next_offset: MetaOapg.properties.next_offset
    results: MetaOapg.properties.results
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["has_more"]) -> MetaOapg.properties.has_more: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["next_offset"]) -> MetaOapg.properties.next_offset: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["results"]) -> MetaOapg.properties.results: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["max_per_page"]) -> MetaOapg.properties.max_per_page: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["has_more", "next_offset", "results", "max_per_page", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["has_more"]) -> MetaOapg.properties.has_more: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["next_offset"]) -> MetaOapg.properties.next_offset: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["results"]) -> MetaOapg.properties.results: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["max_per_page"]) -> MetaOapg.properties.max_per_page: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["has_more", "next_offset", "results", "max_per_page", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        max_per_page: typing.Union[MetaOapg.properties.max_per_page, decimal.Decimal, int, ],
        has_more: typing.Union[MetaOapg.properties.has_more, bool, ],
        next_offset: typing.Union[MetaOapg.properties.next_offset, str, ],
        results: typing.Union[MetaOapg.properties.results, decimal.Decimal, int, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Pagination':
        return super().__new__(
            cls,
            *_args,
            max_per_page=max_per_page,
            has_more=has_more,
            next_offset=next_offset,
            results=results,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class MergeResultSummary(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            added = schemas.IntSchema
            removed = schemas.IntSchema
            changed = schemas.IntSchema
            conflict = schemas.IntSchema
            __annotations__ = {
                "added": added,
                "removed": removed,
                "changed": changed,
                "conflict": conflict,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["added"]) -> MetaOapg.properties.added: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["removed"]) -> MetaOapg.properties.removed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["changed"]) -> MetaOapg.properties.changed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["conflict"]) -> MetaOapg.properties.conflict: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["added", "removed", "changed", "conflict", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["added"]) -> typing.Union[MetaOapg.properties.added, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["removed"]) -> typing.Union[MetaOapg.properties.removed, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["changed"]) -> typing.Union[MetaOapg.properties.changed, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["conflict"]) -> typing.Union[MetaOapg.properties.conflict, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["added", "removed", "changed", "conflict", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        added: typing.Union[MetaOapg.properties.added, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        removed: typing.Union[MetaOapg.properties.removed, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        changed: typing.Union[MetaOapg.properties.changed, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        conflict: typing.Union[MetaOapg.properties.conflict, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'MergeResultSummary':
        return super().__new__(
            cls,
            *_args,
            added=added,
            removed=removed,
            changed=changed,
            conflict=conflict,
            _configuration=_configuration,
            **kwargs,
        )



import typing_extensions

from lakefs_client.paths import PathValues
from lakefs_client.apis.paths.setup_comm_prefs import SetupCommPrefs
from lakefs_client.apis.paths.setup_lakefs import SetupLakefs
from lakefs_client.apis.paths.user import User
from lakefs_client.apis.paths.auth_login import AuthLogin
from lakefs_client.apis.paths.auth_password import AuthPassword
from lakefs_client.apis.paths.auth_password_forgot import AuthPasswordForgot
from lakefs_client.apis.paths.auth_capabilities import AuthCapabilities
from lakefs_client.apis.paths.auth_users import AuthUsers
from lakefs_client.apis.paths.auth_users_user_id import AuthUsersUserId
from lakefs_client.apis.paths.auth_groups import AuthGroups
from lakefs_client.apis.paths.auth_groups_group_id import AuthGroupsGroupId
from lakefs_client.apis.paths.auth_policies import AuthPolicies
from lakefs_client.apis.paths.auth_policies_policy_id import AuthPoliciesPolicyId
from lakefs_client.apis.paths.auth_groups_group_id_members import AuthGroupsGroupIdMembers
from lakefs_client.apis.paths.auth_groups_group_id_members_user_id import AuthGroupsGroupIdMembersUserId
from lakefs_client.apis.paths.auth_users_user_id_credentials import AuthUsersUserIdCredentials
from lakefs_client.apis.paths.auth_users_user_id_credentials_access_key_id import AuthUsersUserIdCredentialsAccessKeyId
from lakefs_client.apis.paths.auth_users_user_id_groups import AuthUsersUserIdGroups
from lakefs_client.apis.paths.auth_users_user_id_policies import AuthUsersUserIdPolicies
from lakefs_client.apis.paths.auth_users_user_id_policies_policy_id import AuthUsersUserIdPoliciesPolicyId
from lakefs_client.apis.paths.auth_groups_group_id_policies import AuthGroupsGroupIdPolicies
from lakefs_client.apis.paths.auth_groups_group_id_policies_policy_id import AuthGroupsGroupIdPoliciesPolicyId
from lakefs_client.apis.paths.repositories import Repositories
from lakefs_client.apis.paths.repositories_repository import RepositoriesRepository
from lakefs_client.apis.paths.repositories_repository_otf_refs_left_ref_diff_right_ref import RepositoriesRepositoryOtfRefsLeftRefDiffRightRef
from lakefs_client.apis.paths.repositories_repository_refs_dump import RepositoriesRepositoryRefsDump
from lakefs_client.apis.paths.repositories_repository_refs_restore import RepositoriesRepositoryRefsRestore
from lakefs_client.apis.paths.repositories_repository_tags import RepositoriesRepositoryTags
from lakefs_client.apis.paths.repositories_repository_tags_tag import RepositoriesRepositoryTagsTag
from lakefs_client.apis.paths.repositories_repository_branches import RepositoriesRepositoryBranches
from lakefs_client.apis.paths.repositories_repository_refs_ref_commits import RepositoriesRepositoryRefsRefCommits
from lakefs_client.apis.paths.repositories_repository_branches_branch_commits import RepositoriesRepositoryBranchesBranchCommits
from lakefs_client.apis.paths.repositories_repository_branches_branch import RepositoriesRepositoryBranchesBranch
from lakefs_client.apis.paths.repositories_repository_branches_branch_revert import RepositoriesRepositoryBranchesBranchRevert
from lakefs_client.apis.paths.repositories_repository_branches_branch_cherry_pick import RepositoriesRepositoryBranchesBranchCherryPick
from lakefs_client.apis.paths.repositories_repository_refs_source_ref_merge_destination_branch import RepositoriesRepositoryRefsSourceRefMergeDestinationBranch
from lakefs_client.apis.paths.repositories_repository_branches_branch_diff import RepositoriesRepositoryBranchesBranchDiff
from lakefs_client.apis.paths.repositories_repository_refs_left_ref_diff_right_ref import RepositoriesRepositoryRefsLeftRefDiffRightRef
from lakefs_client.apis.paths.repositories_repository_commits_commit_id import RepositoriesRepositoryCommitsCommitId
from lakefs_client.apis.paths.repositories_repository_refs_ref_objects import RepositoriesRepositoryRefsRefObjects
from lakefs_client.apis.paths.repositories_repository_branches_branch_staging_backing import RepositoriesRepositoryBranchesBranchStagingBacking
from lakefs_client.apis.paths.repositories_repository_branches_metaranges import RepositoriesRepositoryBranchesMetaranges
from lakefs_client.apis.paths.repositories_repository_branches_ranges import RepositoriesRepositoryBranchesRanges
from lakefs_client.apis.paths.repositories_repository_branches_branch_objects import RepositoriesRepositoryBranchesBranchObjects
from lakefs_client.apis.paths.repositories_repository_branches_branch_objects_delete import RepositoriesRepositoryBranchesBranchObjectsDelete
from lakefs_client.apis.paths.repositories_repository_branches_branch_objects_copy import RepositoriesRepositoryBranchesBranchObjectsCopy
from lakefs_client.apis.paths.repositories_repository_refs_ref_objects_stat import RepositoriesRepositoryRefsRefObjectsStat
from lakefs_client.apis.paths.repositories_repository_refs_ref_objects_underlying_properties import RepositoriesRepositoryRefsRefObjectsUnderlyingProperties
from lakefs_client.apis.paths.repositories_repository_refs_ref_objects_ls import RepositoriesRepositoryRefsRefObjectsLs
from lakefs_client.apis.paths.repositories_repository_refs_branch_symlink import RepositoriesRepositoryRefsBranchSymlink
from lakefs_client.apis.paths.repositories_repository_actions_runs import RepositoriesRepositoryActionsRuns
from lakefs_client.apis.paths.repositories_repository_actions_runs_run_id import RepositoriesRepositoryActionsRunsRunId
from lakefs_client.apis.paths.repositories_repository_actions_runs_run_id_hooks import RepositoriesRepositoryActionsRunsRunIdHooks
from lakefs_client.apis.paths.repositories_repository_actions_runs_run_id_hooks_hook_run_id_output import RepositoriesRepositoryActionsRunsRunIdHooksHookRunIdOutput
from lakefs_client.apis.paths.repositories_repository_metadata_meta_range_meta_range import RepositoriesRepositoryMetadataMetaRangeMetaRange
from lakefs_client.apis.paths.repositories_repository_metadata_range_range import RepositoriesRepositoryMetadataRangeRange
from lakefs_client.apis.paths.repositories_repository_gc_rules import RepositoriesRepositoryGcRules
from lakefs_client.apis.paths.repositories_repository_gc_prepare_commits import RepositoriesRepositoryGcPrepareCommits
from lakefs_client.apis.paths.repositories_repository_gc_prepare_uncommited import RepositoriesRepositoryGcPrepareUncommited
from lakefs_client.apis.paths.repositories_repository_branch_protection import RepositoriesRepositoryBranchProtection
from lakefs_client.apis.paths.healthcheck import Healthcheck
from lakefs_client.apis.paths.config_version import ConfigVersion
from lakefs_client.apis.paths.config_storage import ConfigStorage
from lakefs_client.apis.paths.config_garbage_collection import ConfigGarbageCollection
from lakefs_client.apis.paths.templates_template_location import TemplatesTemplateLocation
from lakefs_client.apis.paths.statistics import Statistics

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.SETUP_COMM_PREFS: SetupCommPrefs,
        PathValues.SETUP_LAKEFS: SetupLakefs,
        PathValues.USER: User,
        PathValues.AUTH_LOGIN: AuthLogin,
        PathValues.AUTH_PASSWORD: AuthPassword,
        PathValues.AUTH_PASSWORD_FORGOT: AuthPasswordForgot,
        PathValues.AUTH_CAPABILITIES: AuthCapabilities,
        PathValues.AUTH_USERS: AuthUsers,
        PathValues.AUTH_USERS_USER_ID: AuthUsersUserId,
        PathValues.AUTH_GROUPS: AuthGroups,
        PathValues.AUTH_GROUPS_GROUP_ID: AuthGroupsGroupId,
        PathValues.AUTH_POLICIES: AuthPolicies,
        PathValues.AUTH_POLICIES_POLICY_ID: AuthPoliciesPolicyId,
        PathValues.AUTH_GROUPS_GROUP_ID_MEMBERS: AuthGroupsGroupIdMembers,
        PathValues.AUTH_GROUPS_GROUP_ID_MEMBERS_USER_ID: AuthGroupsGroupIdMembersUserId,
        PathValues.AUTH_USERS_USER_ID_CREDENTIALS: AuthUsersUserIdCredentials,
        PathValues.AUTH_USERS_USER_ID_CREDENTIALS_ACCESS_KEY_ID: AuthUsersUserIdCredentialsAccessKeyId,
        PathValues.AUTH_USERS_USER_ID_GROUPS: AuthUsersUserIdGroups,
        PathValues.AUTH_USERS_USER_ID_POLICIES: AuthUsersUserIdPolicies,
        PathValues.AUTH_USERS_USER_ID_POLICIES_POLICY_ID: AuthUsersUserIdPoliciesPolicyId,
        PathValues.AUTH_GROUPS_GROUP_ID_POLICIES: AuthGroupsGroupIdPolicies,
        PathValues.AUTH_GROUPS_GROUP_ID_POLICIES_POLICY_ID: AuthGroupsGroupIdPoliciesPolicyId,
        PathValues.REPOSITORIES: Repositories,
        PathValues.REPOSITORIES_REPOSITORY: RepositoriesRepository,
        PathValues.REPOSITORIES_REPOSITORY_OTF_REFS_LEFT_REF_DIFF_RIGHT_REF: RepositoriesRepositoryOtfRefsLeftRefDiffRightRef,
        PathValues.REPOSITORIES_REPOSITORY_REFS_DUMP: RepositoriesRepositoryRefsDump,
        PathValues.REPOSITORIES_REPOSITORY_REFS_RESTORE: RepositoriesRepositoryRefsRestore,
        PathValues.REPOSITORIES_REPOSITORY_TAGS: RepositoriesRepositoryTags,
        PathValues.REPOSITORIES_REPOSITORY_TAGS_TAG: RepositoriesRepositoryTagsTag,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES: RepositoriesRepositoryBranches,
        PathValues.REPOSITORIES_REPOSITORY_REFS_REF_COMMITS: RepositoriesRepositoryRefsRefCommits,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_COMMITS: RepositoriesRepositoryBranchesBranchCommits,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH: RepositoriesRepositoryBranchesBranch,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_REVERT: RepositoriesRepositoryBranchesBranchRevert,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_CHERRYPICK: RepositoriesRepositoryBranchesBranchCherryPick,
        PathValues.REPOSITORIES_REPOSITORY_REFS_SOURCE_REF_MERGE_DESTINATION_BRANCH: RepositoriesRepositoryRefsSourceRefMergeDestinationBranch,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_DIFF: RepositoriesRepositoryBranchesBranchDiff,
        PathValues.REPOSITORIES_REPOSITORY_REFS_LEFT_REF_DIFF_RIGHT_REF: RepositoriesRepositoryRefsLeftRefDiffRightRef,
        PathValues.REPOSITORIES_REPOSITORY_COMMITS_COMMIT_ID: RepositoriesRepositoryCommitsCommitId,
        PathValues.REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS: RepositoriesRepositoryRefsRefObjects,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_STAGING_BACKING: RepositoriesRepositoryBranchesBranchStagingBacking,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_METARANGES: RepositoriesRepositoryBranchesMetaranges,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_RANGES: RepositoriesRepositoryBranchesRanges,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_OBJECTS: RepositoriesRepositoryBranchesBranchObjects,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_OBJECTS_DELETE: RepositoriesRepositoryBranchesBranchObjectsDelete,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_OBJECTS_COPY: RepositoriesRepositoryBranchesBranchObjectsCopy,
        PathValues.REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS_STAT: RepositoriesRepositoryRefsRefObjectsStat,
        PathValues.REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS_UNDERLYING_PROPERTIES: RepositoriesRepositoryRefsRefObjectsUnderlyingProperties,
        PathValues.REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS_LS: RepositoriesRepositoryRefsRefObjectsLs,
        PathValues.REPOSITORIES_REPOSITORY_REFS_BRANCH_SYMLINK: RepositoriesRepositoryRefsBranchSymlink,
        PathValues.REPOSITORIES_REPOSITORY_ACTIONS_RUNS: RepositoriesRepositoryActionsRuns,
        PathValues.REPOSITORIES_REPOSITORY_ACTIONS_RUNS_RUN_ID: RepositoriesRepositoryActionsRunsRunId,
        PathValues.REPOSITORIES_REPOSITORY_ACTIONS_RUNS_RUN_ID_HOOKS: RepositoriesRepositoryActionsRunsRunIdHooks,
        PathValues.REPOSITORIES_REPOSITORY_ACTIONS_RUNS_RUN_ID_HOOKS_HOOK_RUN_ID_OUTPUT: RepositoriesRepositoryActionsRunsRunIdHooksHookRunIdOutput,
        PathValues.REPOSITORIES_REPOSITORY_METADATA_META_RANGE_META_RANGE: RepositoriesRepositoryMetadataMetaRangeMetaRange,
        PathValues.REPOSITORIES_REPOSITORY_METADATA_RANGE_RANGE: RepositoriesRepositoryMetadataRangeRange,
        PathValues.REPOSITORIES_REPOSITORY_GC_RULES: RepositoriesRepositoryGcRules,
        PathValues.REPOSITORIES_REPOSITORY_GC_PREPARE_COMMITS: RepositoriesRepositoryGcPrepareCommits,
        PathValues.REPOSITORIES_REPOSITORY_GC_PREPARE_UNCOMMITED: RepositoriesRepositoryGcPrepareUncommited,
        PathValues.REPOSITORIES_REPOSITORY_BRANCH_PROTECTION: RepositoriesRepositoryBranchProtection,
        PathValues.HEALTHCHECK: Healthcheck,
        PathValues.CONFIG_VERSION: ConfigVersion,
        PathValues.CONFIG_STORAGE: ConfigStorage,
        PathValues.CONFIG_GARBAGECOLLECTION: ConfigGarbageCollection,
        PathValues.TEMPLATES_TEMPLATE_LOCATION: TemplatesTemplateLocation,
        PathValues.STATISTICS: Statistics,
    }
)

path_to_api = PathToApi(
    {
        PathValues.SETUP_COMM_PREFS: SetupCommPrefs,
        PathValues.SETUP_LAKEFS: SetupLakefs,
        PathValues.USER: User,
        PathValues.AUTH_LOGIN: AuthLogin,
        PathValues.AUTH_PASSWORD: AuthPassword,
        PathValues.AUTH_PASSWORD_FORGOT: AuthPasswordForgot,
        PathValues.AUTH_CAPABILITIES: AuthCapabilities,
        PathValues.AUTH_USERS: AuthUsers,
        PathValues.AUTH_USERS_USER_ID: AuthUsersUserId,
        PathValues.AUTH_GROUPS: AuthGroups,
        PathValues.AUTH_GROUPS_GROUP_ID: AuthGroupsGroupId,
        PathValues.AUTH_POLICIES: AuthPolicies,
        PathValues.AUTH_POLICIES_POLICY_ID: AuthPoliciesPolicyId,
        PathValues.AUTH_GROUPS_GROUP_ID_MEMBERS: AuthGroupsGroupIdMembers,
        PathValues.AUTH_GROUPS_GROUP_ID_MEMBERS_USER_ID: AuthGroupsGroupIdMembersUserId,
        PathValues.AUTH_USERS_USER_ID_CREDENTIALS: AuthUsersUserIdCredentials,
        PathValues.AUTH_USERS_USER_ID_CREDENTIALS_ACCESS_KEY_ID: AuthUsersUserIdCredentialsAccessKeyId,
        PathValues.AUTH_USERS_USER_ID_GROUPS: AuthUsersUserIdGroups,
        PathValues.AUTH_USERS_USER_ID_POLICIES: AuthUsersUserIdPolicies,
        PathValues.AUTH_USERS_USER_ID_POLICIES_POLICY_ID: AuthUsersUserIdPoliciesPolicyId,
        PathValues.AUTH_GROUPS_GROUP_ID_POLICIES: AuthGroupsGroupIdPolicies,
        PathValues.AUTH_GROUPS_GROUP_ID_POLICIES_POLICY_ID: AuthGroupsGroupIdPoliciesPolicyId,
        PathValues.REPOSITORIES: Repositories,
        PathValues.REPOSITORIES_REPOSITORY: RepositoriesRepository,
        PathValues.REPOSITORIES_REPOSITORY_OTF_REFS_LEFT_REF_DIFF_RIGHT_REF: RepositoriesRepositoryOtfRefsLeftRefDiffRightRef,
        PathValues.REPOSITORIES_REPOSITORY_REFS_DUMP: RepositoriesRepositoryRefsDump,
        PathValues.REPOSITORIES_REPOSITORY_REFS_RESTORE: RepositoriesRepositoryRefsRestore,
        PathValues.REPOSITORIES_REPOSITORY_TAGS: RepositoriesRepositoryTags,
        PathValues.REPOSITORIES_REPOSITORY_TAGS_TAG: RepositoriesRepositoryTagsTag,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES: RepositoriesRepositoryBranches,
        PathValues.REPOSITORIES_REPOSITORY_REFS_REF_COMMITS: RepositoriesRepositoryRefsRefCommits,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_COMMITS: RepositoriesRepositoryBranchesBranchCommits,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH: RepositoriesRepositoryBranchesBranch,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_REVERT: RepositoriesRepositoryBranchesBranchRevert,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_CHERRYPICK: RepositoriesRepositoryBranchesBranchCherryPick,
        PathValues.REPOSITORIES_REPOSITORY_REFS_SOURCE_REF_MERGE_DESTINATION_BRANCH: RepositoriesRepositoryRefsSourceRefMergeDestinationBranch,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_DIFF: RepositoriesRepositoryBranchesBranchDiff,
        PathValues.REPOSITORIES_REPOSITORY_REFS_LEFT_REF_DIFF_RIGHT_REF: RepositoriesRepositoryRefsLeftRefDiffRightRef,
        PathValues.REPOSITORIES_REPOSITORY_COMMITS_COMMIT_ID: RepositoriesRepositoryCommitsCommitId,
        PathValues.REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS: RepositoriesRepositoryRefsRefObjects,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_STAGING_BACKING: RepositoriesRepositoryBranchesBranchStagingBacking,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_METARANGES: RepositoriesRepositoryBranchesMetaranges,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_RANGES: RepositoriesRepositoryBranchesRanges,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_OBJECTS: RepositoriesRepositoryBranchesBranchObjects,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_OBJECTS_DELETE: RepositoriesRepositoryBranchesBranchObjectsDelete,
        PathValues.REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_OBJECTS_COPY: RepositoriesRepositoryBranchesBranchObjectsCopy,
        PathValues.REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS_STAT: RepositoriesRepositoryRefsRefObjectsStat,
        PathValues.REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS_UNDERLYING_PROPERTIES: RepositoriesRepositoryRefsRefObjectsUnderlyingProperties,
        PathValues.REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS_LS: RepositoriesRepositoryRefsRefObjectsLs,
        PathValues.REPOSITORIES_REPOSITORY_REFS_BRANCH_SYMLINK: RepositoriesRepositoryRefsBranchSymlink,
        PathValues.REPOSITORIES_REPOSITORY_ACTIONS_RUNS: RepositoriesRepositoryActionsRuns,
        PathValues.REPOSITORIES_REPOSITORY_ACTIONS_RUNS_RUN_ID: RepositoriesRepositoryActionsRunsRunId,
        PathValues.REPOSITORIES_REPOSITORY_ACTIONS_RUNS_RUN_ID_HOOKS: RepositoriesRepositoryActionsRunsRunIdHooks,
        PathValues.REPOSITORIES_REPOSITORY_ACTIONS_RUNS_RUN_ID_HOOKS_HOOK_RUN_ID_OUTPUT: RepositoriesRepositoryActionsRunsRunIdHooksHookRunIdOutput,
        PathValues.REPOSITORIES_REPOSITORY_METADATA_META_RANGE_META_RANGE: RepositoriesRepositoryMetadataMetaRangeMetaRange,
        PathValues.REPOSITORIES_REPOSITORY_METADATA_RANGE_RANGE: RepositoriesRepositoryMetadataRangeRange,
        PathValues.REPOSITORIES_REPOSITORY_GC_RULES: RepositoriesRepositoryGcRules,
        PathValues.REPOSITORIES_REPOSITORY_GC_PREPARE_COMMITS: RepositoriesRepositoryGcPrepareCommits,
        PathValues.REPOSITORIES_REPOSITORY_GC_PREPARE_UNCOMMITED: RepositoriesRepositoryGcPrepareUncommited,
        PathValues.REPOSITORIES_REPOSITORY_BRANCH_PROTECTION: RepositoriesRepositoryBranchProtection,
        PathValues.HEALTHCHECK: Healthcheck,
        PathValues.CONFIG_VERSION: ConfigVersion,
        PathValues.CONFIG_STORAGE: ConfigStorage,
        PathValues.CONFIG_GARBAGECOLLECTION: ConfigGarbageCollection,
        PathValues.TEMPLATES_TEMPLATE_LOCATION: TemplatesTemplateLocation,
        PathValues.STATISTICS: Statistics,
    }
)



from lakefs_client.paths.auth_groups_group_id_members_user_id.put import ApiForput
from lakefs_client.paths.auth_groups_group_id_members_user_id.delete import ApiFordelete


class AuthGroupsGroupIdMembersUserId(
    ApiForput,
    ApiFordelete,
):
    pass



from lakefs_client.paths.repositories_repository_branch_protection.get import ApiForget
from lakefs_client.paths.repositories_repository_branch_protection.post import ApiForpost
from lakefs_client.paths.repositories_repository_branch_protection.delete import ApiFordelete


class RepositoriesRepositoryBranchProtection(
    ApiForget,
    ApiForpost,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class RangeMetadata(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "max_key",
            "count",
            "estimated_size",
            "id",
            "min_key",
        }
        
        class properties:
            id = schemas.StrSchema
            min_key = schemas.StrSchema
            max_key = schemas.StrSchema
            count = schemas.IntSchema
            estimated_size = schemas.IntSchema
            __annotations__ = {
                "id": id,
                "min_key": min_key,
                "max_key": max_key,
                "count": count,
                "estimated_size": estimated_size,
            }
    
    max_key: MetaOapg.properties.max_key
    count: MetaOapg.properties.count
    estimated_size: MetaOapg.properties.estimated_size
    id: MetaOapg.properties.id
    min_key: MetaOapg.properties.min_key
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["min_key"]) -> MetaOapg.properties.min_key: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["max_key"]) -> MetaOapg.properties.max_key: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["count"]) -> MetaOapg.properties.count: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["estimated_size"]) -> MetaOapg.properties.estimated_size: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "min_key", "max_key", "count", "estimated_size", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["min_key"]) -> MetaOapg.properties.min_key: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["max_key"]) -> MetaOapg.properties.max_key: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["count"]) -> MetaOapg.properties.count: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["estimated_size"]) -> MetaOapg.properties.estimated_size: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "min_key", "max_key", "count", "estimated_size", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        max_key: typing.Union[MetaOapg.properties.max_key, str, ],
        count: typing.Union[MetaOapg.properties.count, decimal.Decimal, int, ],
        estimated_size: typing.Union[MetaOapg.properties.estimated_size, decimal.Decimal, int, ],
        id: typing.Union[MetaOapg.properties.id, str, ],
        min_key: typing.Union[MetaOapg.properties.min_key, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'RangeMetadata':
        return super().__new__(
            cls,
            *_args,
            max_key=max_key,
            count=count,
            estimated_size=estimated_size,
            id=id,
            min_key=min_key,
            _configuration=_configuration,
            **kwargs,
        )



from lakefs_client.paths.auth_policies_policy_id.get import ApiForget
from lakefs_client.paths.auth_policies_policy_id.put import ApiForput
from lakefs_client.paths.auth_policies_policy_id.delete import ApiFordelete


class AuthPoliciesPolicyId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_branches_branch_commits.post import Commit
from lakefs_client.paths.repositories_repository_commits_commit_id.get import GetCommit
from lakefs_client.paths.repositories_repository_branches_branch_commits.get import LogBranchCommits


class CommitsApi(
    Commit,
    GetCommit,
    LogBranchCommits,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from lakefs_client.paths.repositories_repository_branches_branch_objects.put import ApiForput
from lakefs_client.paths.repositories_repository_branches_branch_objects.post import ApiForpost
from lakefs_client.paths.repositories_repository_branches_branch_objects.delete import ApiFordelete


class RepositoriesRepositoryBranchesBranchObjects(
    ApiForput,
    ApiForpost,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_actions_runs_run_id.get import GetRun
from lakefs_client.paths.repositories_repository_actions_runs_run_id_hooks_hook_run_id_output.get import GetRunHookOutput
from lakefs_client.paths.repositories_repository_actions_runs.get import ListRepositoryRuns
from lakefs_client.paths.repositories_repository_actions_runs_run_id_hooks.get import ListRunHooks


class ActionsApi(
    GetRun,
    GetRunHookOutput,
    ListRepositoryRuns,
    ListRunHooks,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from lakefs_client.paths.repositories_repository_refs_ref_objects_underlying_properties.get import ApiForget


class RepositoriesRepositoryRefsRefObjectsUnderlyingProperties(
    ApiForget,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class StageRangeCreation(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "fromSourceURI",
            "prepend",
            "after",
        }
        
        class properties:
            fromSourceURI = schemas.StrSchema
            after = schemas.StrSchema
            prepend = schemas.StrSchema
            continuation_token = schemas.StrSchema
            __annotations__ = {
                "fromSourceURI": fromSourceURI,
                "after": after,
                "prepend": prepend,
                "continuation_token": continuation_token,
            }
    
    fromSourceURI: MetaOapg.properties.fromSourceURI
    prepend: MetaOapg.properties.prepend
    after: MetaOapg.properties.after
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fromSourceURI"]) -> MetaOapg.properties.fromSourceURI: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["after"]) -> MetaOapg.properties.after: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["prepend"]) -> MetaOapg.properties.prepend: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["continuation_token"]) -> MetaOapg.properties.continuation_token: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["fromSourceURI", "after", "prepend", "continuation_token", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fromSourceURI"]) -> MetaOapg.properties.fromSourceURI: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["after"]) -> MetaOapg.properties.after: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["prepend"]) -> MetaOapg.properties.prepend: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["continuation_token"]) -> typing.Union[MetaOapg.properties.continuation_token, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["fromSourceURI", "after", "prepend", "continuation_token", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        fromSourceURI: typing.Union[MetaOapg.properties.fromSourceURI, str, ],
        prepend: typing.Union[MetaOapg.properties.prepend, str, ],
        after: typing.Union[MetaOapg.properties.after, str, ],
        continuation_token: typing.Union[MetaOapg.properties.continuation_token, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'StageRangeCreation':
        return super().__new__(
            cls,
            *_args,
            fromSourceURI=fromSourceURI,
            prepend=prepend,
            after=after,
            continuation_token=continuation_token,
            _configuration=_configuration,
            **kwargs,
        )



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from lakefs_client.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    SETUP_COMM_PREFS = "/setup_comm_prefs"
    SETUP_LAKEFS = "/setup_lakefs"
    USER = "/user"
    AUTH_LOGIN = "/auth/login"
    AUTH_PASSWORD = "/auth/password"
    AUTH_PASSWORD_FORGOT = "/auth/password/forgot"
    AUTH_CAPABILITIES = "/auth/capabilities"
    AUTH_USERS = "/auth/users"
    AUTH_USERS_USER_ID = "/auth/users/{userId}"
    AUTH_GROUPS = "/auth/groups"
    AUTH_GROUPS_GROUP_ID = "/auth/groups/{groupId}"
    AUTH_POLICIES = "/auth/policies"
    AUTH_POLICIES_POLICY_ID = "/auth/policies/{policyId}"
    AUTH_GROUPS_GROUP_ID_MEMBERS = "/auth/groups/{groupId}/members"
    AUTH_GROUPS_GROUP_ID_MEMBERS_USER_ID = "/auth/groups/{groupId}/members/{userId}"
    AUTH_USERS_USER_ID_CREDENTIALS = "/auth/users/{userId}/credentials"
    AUTH_USERS_USER_ID_CREDENTIALS_ACCESS_KEY_ID = "/auth/users/{userId}/credentials/{accessKeyId}"
    AUTH_USERS_USER_ID_GROUPS = "/auth/users/{userId}/groups"
    AUTH_USERS_USER_ID_POLICIES = "/auth/users/{userId}/policies"
    AUTH_USERS_USER_ID_POLICIES_POLICY_ID = "/auth/users/{userId}/policies/{policyId}"
    AUTH_GROUPS_GROUP_ID_POLICIES = "/auth/groups/{groupId}/policies"
    AUTH_GROUPS_GROUP_ID_POLICIES_POLICY_ID = "/auth/groups/{groupId}/policies/{policyId}"
    REPOSITORIES = "/repositories"
    REPOSITORIES_REPOSITORY = "/repositories/{repository}"
    REPOSITORIES_REPOSITORY_OTF_REFS_LEFT_REF_DIFF_RIGHT_REF = "/repositories/{repository}/otf/refs/{left_ref}/diff/{right_ref}"
    REPOSITORIES_REPOSITORY_REFS_DUMP = "/repositories/{repository}/refs/dump"
    REPOSITORIES_REPOSITORY_REFS_RESTORE = "/repositories/{repository}/refs/restore"
    REPOSITORIES_REPOSITORY_TAGS = "/repositories/{repository}/tags"
    REPOSITORIES_REPOSITORY_TAGS_TAG = "/repositories/{repository}/tags/{tag}"
    REPOSITORIES_REPOSITORY_BRANCHES = "/repositories/{repository}/branches"
    REPOSITORIES_REPOSITORY_REFS_REF_COMMITS = "/repositories/{repository}/refs/{ref}/commits"
    REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_COMMITS = "/repositories/{repository}/branches/{branch}/commits"
    REPOSITORIES_REPOSITORY_BRANCHES_BRANCH = "/repositories/{repository}/branches/{branch}"
    REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_REVERT = "/repositories/{repository}/branches/{branch}/revert"
    REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_CHERRYPICK = "/repositories/{repository}/branches/{branch}/cherry-pick"
    REPOSITORIES_REPOSITORY_REFS_SOURCE_REF_MERGE_DESTINATION_BRANCH = "/repositories/{repository}/refs/{sourceRef}/merge/{destinationBranch}"
    REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_DIFF = "/repositories/{repository}/branches/{branch}/diff"
    REPOSITORIES_REPOSITORY_REFS_LEFT_REF_DIFF_RIGHT_REF = "/repositories/{repository}/refs/{leftRef}/diff/{rightRef}"
    REPOSITORIES_REPOSITORY_COMMITS_COMMIT_ID = "/repositories/{repository}/commits/{commitId}"
    REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS = "/repositories/{repository}/refs/{ref}/objects"
    REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_STAGING_BACKING = "/repositories/{repository}/branches/{branch}/staging/backing"
    REPOSITORIES_REPOSITORY_BRANCHES_METARANGES = "/repositories/{repository}/branches/metaranges"
    REPOSITORIES_REPOSITORY_BRANCHES_RANGES = "/repositories/{repository}/branches/ranges"
    REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_OBJECTS = "/repositories/{repository}/branches/{branch}/objects"
    REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_OBJECTS_DELETE = "/repositories/{repository}/branches/{branch}/objects/delete"
    REPOSITORIES_REPOSITORY_BRANCHES_BRANCH_OBJECTS_COPY = "/repositories/{repository}/branches/{branch}/objects/copy"
    REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS_STAT = "/repositories/{repository}/refs/{ref}/objects/stat"
    REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS_UNDERLYING_PROPERTIES = "/repositories/{repository}/refs/{ref}/objects/underlyingProperties"
    REPOSITORIES_REPOSITORY_REFS_REF_OBJECTS_LS = "/repositories/{repository}/refs/{ref}/objects/ls"
    REPOSITORIES_REPOSITORY_REFS_BRANCH_SYMLINK = "/repositories/{repository}/refs/{branch}/symlink"
    REPOSITORIES_REPOSITORY_ACTIONS_RUNS = "/repositories/{repository}/actions/runs"
    REPOSITORIES_REPOSITORY_ACTIONS_RUNS_RUN_ID = "/repositories/{repository}/actions/runs/{run_id}"
    REPOSITORIES_REPOSITORY_ACTIONS_RUNS_RUN_ID_HOOKS = "/repositories/{repository}/actions/runs/{run_id}/hooks"
    REPOSITORIES_REPOSITORY_ACTIONS_RUNS_RUN_ID_HOOKS_HOOK_RUN_ID_OUTPUT = "/repositories/{repository}/actions/runs/{run_id}/hooks/{hook_run_id}/output"
    REPOSITORIES_REPOSITORY_METADATA_META_RANGE_META_RANGE = "/repositories/{repository}/metadata/meta_range/{meta_range}"
    REPOSITORIES_REPOSITORY_METADATA_RANGE_RANGE = "/repositories/{repository}/metadata/range/{range}"
    REPOSITORIES_REPOSITORY_GC_RULES = "/repositories/{repository}/gc/rules"
    REPOSITORIES_REPOSITORY_GC_PREPARE_COMMITS = "/repositories/{repository}/gc/prepare_commits"
    REPOSITORIES_REPOSITORY_GC_PREPARE_UNCOMMITED = "/repositories/{repository}/gc/prepare_uncommited"
    REPOSITORIES_REPOSITORY_BRANCH_PROTECTION = "/repositories/{repository}/branch_protection"
    HEALTHCHECK = "/healthcheck"
    CONFIG_VERSION = "/config/version"
    CONFIG_STORAGE = "/config/storage"
    CONFIG_GARBAGECOLLECTION = "/config/garbage-collection"
    TEMPLATES_TEMPLATE_LOCATION = "/templates/{template_location}"
    STATISTICS = "/statistics"



from lakefs_client.paths.repositories_repository_branches_branch_staging_backing.get import ApiForget
from lakefs_client.paths.repositories_repository_branches_branch_staging_backing.put import ApiForput


class RepositoriesRepositoryBranchesBranchStagingBacking(
    ApiForget,
    ApiForput,
):
    pass



from lakefs_client.paths.repositories_repository_actions_runs_run_id_hooks_hook_run_id_output.get import ApiForget


class RepositoriesRepositoryActionsRunsRunIdHooksHookRunIdOutput(
    ApiForget,
):
    pass



from lakefs_client.paths.repositories_repository.get import ApiForget
from lakefs_client.paths.repositories_repository.delete import ApiFordelete


class RepositoriesRepository(
    ApiForget,
    ApiFordelete,
):
    pass



from lakefs_client.paths.repositories_repository_gc_rules.get import ApiForget
from lakefs_client.paths.repositories_repository_gc_rules.post import ApiForpost
from lakefs_client.paths.repositories_repository_gc_rules.delete import ApiFordelete


class RepositoriesRepositoryGcRules(
    ApiForget,
    ApiForpost,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class HookRun(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "start_time",
            "hook_id",
            "action",
            "hook_run_id",
            "status",
        }
        
        class properties:
            hook_run_id = schemas.StrSchema
            action = schemas.StrSchema
            hook_id = schemas.StrSchema
            start_time = schemas.DateTimeSchema
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "failed": "FAILED",
                        "completed": "COMPLETED",
                    }
                
                @schemas.classproperty
                def FAILED(cls):
                    return cls("failed")
                
                @schemas.classproperty
                def COMPLETED(cls):
                    return cls("completed")
            end_time = schemas.DateTimeSchema
            __annotations__ = {
                "hook_run_id": hook_run_id,
                "action": action,
                "hook_id": hook_id,
                "start_time": start_time,
                "status": status,
                "end_time": end_time,
            }
    
    start_time: MetaOapg.properties.start_time
    hook_id: MetaOapg.properties.hook_id
    action: MetaOapg.properties.action
    hook_run_id: MetaOapg.properties.hook_run_id
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hook_run_id"]) -> MetaOapg.properties.hook_run_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["action"]) -> MetaOapg.properties.action: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hook_id"]) -> MetaOapg.properties.hook_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["start_time"]) -> MetaOapg.properties.start_time: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["end_time"]) -> MetaOapg.properties.end_time: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["hook_run_id", "action", "hook_id", "start_time", "status", "end_time", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hook_run_id"]) -> MetaOapg.properties.hook_run_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["action"]) -> MetaOapg.properties.action: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hook_id"]) -> MetaOapg.properties.hook_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["start_time"]) -> MetaOapg.properties.start_time: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["end_time"]) -> typing.Union[MetaOapg.properties.end_time, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["hook_run_id", "action", "hook_id", "start_time", "status", "end_time", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        start_time: typing.Union[MetaOapg.properties.start_time, str, datetime, ],
        hook_id: typing.Union[MetaOapg.properties.hook_id, str, ],
        action: typing.Union[MetaOapg.properties.action, str, ],
        hook_run_id: typing.Union[MetaOapg.properties.hook_run_id, str, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        end_time: typing.Union[MetaOapg.properties.end_time, str, datetime, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'HookRun':
        return super().__new__(
            cls,
            *_args,
            start_time=start_time,
            hook_id=hook_id,
            action=action,
            hook_run_id=hook_run_id,
            status=status,
            end_time=end_time,
            _configuration=_configuration,
            **kwargs,
        )



from lakefs_client.paths.repositories_repository_branches_branch.get import ApiForget
from lakefs_client.paths.repositories_repository_branches_branch.put import ApiForput
from lakefs_client.paths.repositories_repository_branches_branch.delete import ApiFordelete


class RepositoriesRepositoryBranchesBranch(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from lakefs_client.paths.repositories_repository_refs_dump import Api

from lakefs_client.paths import PathValues

path = PathValues.REPOSITORIES_REPOSITORY_REFS_DUMP


from lakefs_client.paths.repositories_repository_refs_source_ref_merge_destination_branch.get import ApiForget
from lakefs_client.paths.repositories_repository_refs_source_ref_merge_destination_branch.post import ApiForpost


class RepositoriesRepositoryRefsSourceRefMergeDestinationBranch(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class Diff(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "path",
            "path_type",
            "type",
        }
        
        class properties:
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "added": "ADDED",
                        "removed": "REMOVED",
                        "changed": "CHANGED",
                        "conflict": "CONFLICT",
                        "prefix_changed": "PREFIX_CHANGED",
                    }
                
                @schemas.classproperty
                def ADDED(cls):
                    return cls("added")
                
                @schemas.classproperty
                def REMOVED(cls):
                    return cls("removed")
                
                @schemas.classproperty
                def CHANGED(cls):
                    return cls("changed")
                
                @schemas.classproperty
                def CONFLICT(cls):
                    return cls("conflict")
                
                @schemas.classproperty
                def PREFIX_CHANGED(cls):
                    return cls("prefix_changed")
            path = schemas.StrSchema
            
            
            class path_type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "common_prefix": "COMMON_PREFIX",
                        "object": "OBJECT",
                    }
                
                @schemas.classproperty
                def COMMON_PREFIX(cls):
                    return cls("common_prefix")
                
                @schemas.classproperty
                def OBJECT(cls):
                    return cls("object")
            size_bytes = schemas.Int64Schema
            __annotations__ = {
                "type": type,
                "path": path,
                "path_type": path_type,
                "size_bytes": size_bytes,
            }
    
    path: MetaOapg.properties.path
    path_type: MetaOapg.properties.path_type
    type: MetaOapg.properties.type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["path"]) -> MetaOapg.properties.path: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["path_type"]) -> MetaOapg.properties.path_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["size_bytes"]) -> MetaOapg.properties.size_bytes: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["type", "path", "path_type", "size_bytes", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["path"]) -> MetaOapg.properties.path: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["path_type"]) -> MetaOapg.properties.path_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["size_bytes"]) -> typing.Union[MetaOapg.properties.size_bytes, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["type", "path", "path_type", "size_bytes", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        path: typing.Union[MetaOapg.properties.path, str, ],
        path_type: typing.Union[MetaOapg.properties.path_type, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        size_bytes: typing.Union[MetaOapg.properties.size_bytes, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Diff':
        return super().__new__(
            cls,
            *_args,
            path=path,
            path_type=path_type,
            type=type,
            size_bytes=size_bytes,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_branches_branch_objects_copy.post import CopyObject
from lakefs_client.paths.repositories_repository_branches_branch_objects.delete import DeleteObject
from lakefs_client.paths.repositories_repository_branches_branch_objects_delete.post import DeleteObjects
from lakefs_client.paths.repositories_repository_refs_ref_objects.get import GetObject
from lakefs_client.paths.repositories_repository_refs_ref_objects_underlying_properties.get import GetUnderlyingProperties
from lakefs_client.paths.repositories_repository_refs_ref_objects.head import HeadObject
from lakefs_client.paths.repositories_repository_refs_ref_objects_ls.get import ListObjects
from lakefs_client.paths.repositories_repository_branches_branch_objects.put import StageObject
from lakefs_client.paths.repositories_repository_refs_ref_objects_stat.get import StatObject
from lakefs_client.paths.repositories_repository_branches_branch_objects.post import UploadObject


class ObjectsApi(
    CopyObject,
    DeleteObject,
    DeleteObjects,
    GetObject,
    GetUnderlyingProperties,
    HeadObject,
    ListObjects,
    StageObject,
    StatObject,
    UploadObject,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from lakefs_client.paths.repositories_repository_tags.get import ApiForget
from lakefs_client.paths.repositories_repository_tags.post import ApiForpost


class RepositoriesRepositoryTags(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

import unittest

import lakefs_client
from lakefs_client.model.object_stats_list import ObjectStatsList
from lakefs_client import configuration


class TestObjectStatsList(unittest.TestCase):
    """ObjectStatsList unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
